@@ -29,3 +29,12 @@ def watch_docs(path="./docs/", src_path=None, command="make html"):
 def deploy(setup_file='./setup.py'):
     fab.local('vim {}'.format(setup_file))
     fab.local('python {} sdist upload'.format(setup_file))
+
+
+def push():
+    fab.local('git status')
+    fab.local('git diff')
+    ans = raw_input('Continue git push? [y/N]: ')
+    if ans.lower().startswith('y'):
+        fab.local('git add .')
+        fab.local('git push')
