@@ -8,6 +8,7 @@ from livereload import server
 
 from .util import register_keep_alive
 
+
 logger = logging.getLogger(__name__)
 DEFAULT_PORT = 5500
 
@@ -28,7 +29,7 @@ def live_reload(files=None, port=DEFAULT_PORT, throttle=3, fns=None, reload=True
     :return: void
     """
     # Monkey patch livereload handler
-    from .monkey.livereload_forcehandler import patch; patch()
+    from .monkey import livereload_forcehandler
     from .watch import watch
     from requests import get
     import urllib
@@ -41,6 +42,7 @@ def live_reload(files=None, port=DEFAULT_PORT, throttle=3, fns=None, reload=True
     thread.start_new_thread(run_server, ())
 
     def reload_file(event, fns):
+        logger.info("Reloading from file: %s", event.src_path)
         path = urllib.urlencode(dict(path=event.src_path))
         get('http://127.0.0.1:%d/forcereload?%s' % (port, path))
         if callback:
